==> qtjambi-qt3danimation-jre8-5.15.4-sources.jar: io/qt/qt3d/animation/QAnimationClipData.java <==
package io.qt.qt3d.animation;


/**
 * <p>Class containing the animation data</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qt3danimation-qanimationclipdata.html">Qt3DAnimation::QAnimationClipData</a></p>
 */
public class QAnimationClipData extends io.qt.QtObject
    implements java.lang.Iterable<io.qt.qt3d.animation.QChannel>,
            java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    

    
    public QAnimationClipData(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QAnimationClipData instance);
    
    public QAnimationClipData(io.qt.qt3d.animation.QAnimationClipData arg__1){
        super((QPrivateConstructor)null);
        initialize_native(this, arg__1);
    }
    
    private native static void initialize_native(QAnimationClipData instance, io.qt.qt3d.animation.QAnimationClipData arg__1);
    
    @io.qt.QtUninvokable
    public final void appendChannel(io.qt.qt3d.animation.QChannel c){
        appendChannel_native_cref_Qt3DAnimation_QChannel(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(c));
    }
    
    @io.qt.QtUninvokable
    private native void appendChannel_native_cref_Qt3DAnimation_QChannel(long __this__nativeId, long c);
    
    @io.qt.QtUninvokable
    protected final io.qt.core.QIterator<io.qt.qt3d.animation.QChannel> begin(){
        return begin_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QIterator<io.qt.qt3d.animation.QChannel> begin_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final int channelCount(){
        return channelCount_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int channelCount_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearChannels(){
        clearChannels_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearChannels_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    protected final io.qt.core.QIterator<io.qt.qt3d.animation.QChannel> end(){
        return end_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QIterator<io.qt.qt3d.animation.QChannel> end_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void insertChannel(int index, io.qt.qt3d.animation.QChannel c){
        insertChannel_native_int_cref_Qt3DAnimation_QChannel(QtJambi_LibraryUtilities.internal.nativeId(this), index, QtJambi_LibraryUtilities.internal.checkedNativeId(c));
    }
    
    @io.qt.QtUninvokable
    private native void insertChannel_native_int_cref_Qt3DAnimation_QChannel(long __this__nativeId, int index, long c);
    
    @io.qt.QtUninvokable
    public final boolean isValid(){
        return isValid_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isValid_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final java.lang.String name(){
        return name_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String name_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void removeChannel(int index){
        removeChannel_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), index);
    }
    
    @io.qt.QtUninvokable
    private native void removeChannel_native_int(long __this__nativeId, int index);
    
    @io.qt.QtUninvokable
    public final void setName(java.lang.String name){
        setName_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), name);
    }
    
    @io.qt.QtUninvokable
    private native void setName_native_cref_QString(long __this__nativeId, java.lang.String name);
    
    
    @Override
    public java.util.Iterator<io.qt.qt3d.animation.QChannel> iterator() {
        return begin().iterator();
    }
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QAnimationClipData(QPrivateConstructor p) { super(p); } 
    

    @Override
    @io.qt.QtUninvokable
    public boolean equals(Object other) {
        if(other instanceof io.qt.qt3d.animation.QAnimationClipData)
            return hashCode()==other.hashCode();
        else return super.equals(other);    }


    @io.qt.QtUninvokable
    @Override
    public int hashCode() {
        return hashCode_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @io.qt.QtUninvokable
    private native static int hashCode_native(long __this_nativeId);
    
    @Override
    public QAnimationClipData clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QAnimationClipData clone_native(long __this_nativeId);
}

==> qtjambi-qt3danimation-jre8-6.3.0-sources.jar: io/qt/qt3d/animation/QAnimationClipData.java <==
package io.qt.qt3d.animation;


/**
 * <p>Class containing the animation data</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qt3danimation-qanimationclipdata.html">Qt3DAnimation::QAnimationClipData</a></p>
 */
public class QAnimationClipData extends io.qt.QtObject
    implements java.lang.Iterable<io.qt.qt3d.animation.QChannel>,
            java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    

    
    public QAnimationClipData(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QAnimationClipData instance);
    
    public QAnimationClipData(io.qt.qt3d.animation.QAnimationClipData arg__1){
        super((QPrivateConstructor)null);
        initialize_native(this, arg__1);
    }
    
    private native static void initialize_native(QAnimationClipData instance, io.qt.qt3d.animation.QAnimationClipData arg__1);
    
    @io.qt.QtUninvokable
    public final void appendChannel(io.qt.qt3d.animation.QChannel c){
        appendChannel_native_cref_Qt3DAnimation_QChannel(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(c));
    }
    
    @io.qt.QtUninvokable
    private native void appendChannel_native_cref_Qt3DAnimation_QChannel(long __this__nativeId, long c);
    
    @io.qt.QtUninvokable
    protected final io.qt.core.QIterator<io.qt.qt3d.animation.QChannel> begin(){
        return begin_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QIterator<io.qt.qt3d.animation.QChannel> begin_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final int channelCount(){
        return channelCount_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int channelCount_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearChannels(){
        clearChannels_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearChannels_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    protected final io.qt.core.QIterator<io.qt.qt3d.animation.QChannel> end(){
        return end_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QIterator<io.qt.qt3d.animation.QChannel> end_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void insertChannel(int index, io.qt.qt3d.animation.QChannel c){
        insertChannel_native_int_cref_Qt3DAnimation_QChannel(QtJambi_LibraryUtilities.internal.nativeId(this), index, QtJambi_LibraryUtilities.internal.checkedNativeId(c));
    }
    
    @io.qt.QtUninvokable
    private native void insertChannel_native_int_cref_Qt3DAnimation_QChannel(long __this__nativeId, int index, long c);
    
    @io.qt.QtUninvokable
    public final boolean isValid(){
        return isValid_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isValid_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final java.lang.String name(){
        return name_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String name_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    private final boolean operator_equal(io.qt.qt3d.animation.QAnimationClipData rhs){
        return operator_equal_native_cref_Qt3DAnimation_QAnimationClipData(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(rhs));
    }
    
    @io.qt.QtUninvokable
    private native boolean operator_equal_native_cref_Qt3DAnimation_QAnimationClipData(long __this__nativeId, long rhs);
    
    @io.qt.QtUninvokable
    public final void removeChannel(int index){
        removeChannel_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), index);
    }
    
    @io.qt.QtUninvokable
    private native void removeChannel_native_int(long __this__nativeId, int index);
    
    @io.qt.QtUninvokable
    public final void setName(java.lang.String name){
        setName_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), name);
    }
    
    @io.qt.QtUninvokable
    private native void setName_native_cref_QString(long __this__nativeId, java.lang.String name);
    
    
    @Override
    public java.util.Iterator<io.qt.qt3d.animation.QChannel> iterator() {
        return begin().iterator();
    }
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QAnimationClipData(QPrivateConstructor p) { super(p); } 
    

    @Override
    @io.qt.QtUninvokable
    public boolean equals(Object other) {
        if (other instanceof io.qt.qt3d.animation.QAnimationClipData) {
            return operator_equal((io.qt.qt3d.animation.QAnimationClipData) other);
        }

        return false;
    }


    @io.qt.QtUninvokable
    @Override
    public int hashCode() {
        return hashCode_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @io.qt.QtUninvokable
    private native static int hashCode_native(long __this_nativeId);
    
    @Override
    public QAnimationClipData clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QAnimationClipData clone_native(long __this_nativeId);
}
